@@ -232,12 +232,11 @@ class Range(models.Model):
     includes_all_products = models.BooleanField(default=False)
     included_products = models.ManyToManyField('catalogue.Product', related_name='includes', blank=True)
     excluded_products = models.ManyToManyField('catalogue.Product', related_name='excludes', blank=True)
-    classes = models.ManyToManyField('catalogue.ProductClass', related_name='classes', blank=True)
+    classes = models.ManyToManyField('catalogue.ProductClass', blank=True)
     included_categories = models.ManyToManyField('catalogue.Category', related_name='includes', blank=True)
 
     __included_product_ids = None
     __excluded_product_ids = None
-    __class_ids = None
 
     def __unicode__(self):
         return self.name
@@ -281,8 +280,13 @@ class Range(models.Model):
         return self.__excluded_product_ids
 
     def _class_ids(self):
-        if None == self.__class_ids:
-            self.__class_ids = [row['id'] for row in self.classes.values('id')]
+        if not hasattr(self, '__class_ids'):
+            # This is deliberately disabled as it causes a nasty problem in the
+            # Landmark project which we've been unable to reproduce.  Will
+            # re-enable when the problem is resolved.  Apologies for any
+            # inconvenience.
+            #self.__class_ids = [row['id'] for row in self.klasses.values('id')]
+            self.__class_ids = []
         return self.__class_ids
 
 
@@ -490,16 +494,17 @@ class AbsoluteDiscountBenefit(Benefit):
 
                 # Update line with discounts
                 line_discount = self.round(min(remaining_discount, quantity_affected * price))
-                if not condition:
+                if condition:
+                    # Pass zero as quantity to avoid double consumption
+                    line.discount(line_discount, 0)
+                else:
                     line.discount(line_discount, quantity_affected)
-
                 # Update loop vars
                 affected_items += quantity_affected
                 remaining_discount -= line_discount
                 discount += line_discount
         if discount > 0 and condition:
             condition.consume_items(basket)
-
         return discount
 
 
